module  hyperram (
        //Clock and Reset
        input  wire        c10_clk50m    ,
        input  wire        hbus_clk_50m  ,  
        input  wire        c10_clk_adj   ,  
        input  wire        enet_clk_125m ,
        input  wire        c10_resetn    ,

        //LED PB DIPSW
        output wire [3:0]  user_led ,
        input  wire [3:0]  user_pb  ,
        input  wire [2:0]  user_dip ,

        //Ethernet Port 
        output wire        enet_mdc        ,
        inout  wire        enet_mdio       ,
        
        input  wire        enet_int        ,     
        output wire        enet_resetn     ,	    
        input  wire        enet_rx_clk     ,     
        output wire        enet_tx_clk     ,    
        input  wire [3:0]  enet_rx_d       ,       
        output wire [3:0]  enet_tx_d       ,       
        output wire        enet_tx_en      ,      
        input  wire        enet_rx_dv      ,      
//        input  wire        enet_led_link100,

        //PMOD PORT
        inout  wire [7:0]  pmod_d   ,

        //Side Bus
        input  wire         usb_reset_n        ,
        input  wire         c10_usb_clk        ,
        input  wire         usb_wr_n           ,
        input  wire         usb_rd_n           ,
        input  wire         usb_oe_n           ,
        output wire         usb_full           ,
        output wire         usb_empty          ,
        inout  wire   [7:0] usb_data           ,
        inout  wire   [1:0] usb_addr           ,
        inout  tri1         usb_scl            ,
        inout  tri1         usb_sda            ,
        
        
        //User IO & Clock
        inout  wire [35:0]  gpio            ,
        
        //ARDUINO IO
        inout  wire [13:0]  arduino_io      ,
        output wire         arduino_rstn    ,
        inout  wire         arduino_sda     ,
        inout  wire         arduino_scl     ,        
        inout  wire         arduino_adc_sda ,
        inout  wire         arduino_adc_scl ,

        //Cyclone 10 to MAX 10 IO
        inout  wire [3:0]  c10_m10_io   ,       
        
        //HyperRAM IO
        output wire         hbus_rstn   ,
        output wire         hbus_clk0p  ,
        output wire         hbus_clk0n  ,
        output wire         hbus_cs2n   , //HyperRAM chip select
        inout  wire         hbus_rwds   ,
        inout  wire [7:0]   hbus_dq     ,
        output wire         hbus_cs1n   , //For HyperFlash
        input  wire         hbus_rston  , //For HyperFlash
        input  wire         hbus_intn     //For HyperFlash

        //QSPI
//        output wire    qspi_dclk   ,
//        output wire    qspi_sce    ,
//        output wire    qspi_sdo    ,
//        input  wire    qspi_data0  

        );

//Heart-beat counter
reg   [25:0]  heart_beat_cnt;


assign system_resetn = c10_resetn ;




hyperram_q_sys	hyperram_inst0(
	.clk_clk                          (hbus_clk_50m     ),
	.rst_reset_n                      (c10_resetn       ),

//hyperbus signals
  .hyperbus_controller_top_HB_RSTn  (hbus_rstn                 ) ,          //             hyperbus_controller_top.HB_RSTn
  .hyperbus_controller_top_HB_CLK0  (hbus_clk0p                ) ,          //                                    .HB_CLK0
  .hyperbus_controller_top_HB_CLK0n (hbus_clk0n                ) ,          //                                    .HB_CLK0n
  .hyperbus_controller_top_HB_CLK1  (                          ) ,          //                                    .HB_CLK1
  .hyperbus_controller_top_HB_CLK1n (                          ) ,          //                                    .HB_CLK1n
  .hyperbus_controller_top_HB_CS0n  (                          ) ,          //                                    .HB_CS0n
  .hyperbus_controller_top_HB_CS1n  (hbus_cs2n                 ) ,          //                                    .HB_CS1n
  .hyperbus_controller_top_HB_WPn   (                          ) ,          //                                    .HB_WPn
  .hyperbus_controller_top_HB_RWDS  (hbus_rwds                 ) ,          //                                    .HB_RWDS
  .hyperbus_controller_top_HB_dq    (hbus_dq                   ) ,          //                                    .HB_dq
  .hyperbus_controller_top_HB_RSTOn (hbus_rston                ) ,          //                                    .HB_RSTOn
  .hyperbus_controller_top_HB_INTn  (hbus_intn                 ) ,          //                                    .HB_INTn

  .master_driver_msgdma_0_conduit_end_error_mon  (local_error_mon   ), //  master_driver_msgdma_0_conduit_end.error_mon
  .master_driver_msgdma_0_conduit_end_status_mon (local_status_mon  )  //                                    .status_mon
 );


reg [25:0] heart_beat_cnt_clk_adj ;
//Heart beat by c10_clk_adj clock
always @(posedge c10_clk_adj or negedge c10_resetn)
  if (!c10_resetn)
      heart_beat_cnt_clk_adj <= 26'h0; //0x3FFFFFF
  else
      heart_beat_cnt_clk_adj <= heart_beat_cnt_clk_adj + 1'b1;


reg [25:0] heart_beat_cnt_clk_125m ;
//Heart beat by enet_clk_125m clock
always @(posedge enet_clk_125m or negedge c10_resetn)
  if (!c10_resetn)
      heart_beat_cnt_clk_125m <= 26'h0; //0x3FFFFFF
  else
      heart_beat_cnt_clk_125m <= heart_beat_cnt_clk_125m + 1'b1;


reg [25:0] heart_beat_cnt_hbus_clk ;
//Heart beat by 50MHz clock
always @(posedge hbus_clk_50m or negedge c10_resetn)
  if (!c10_resetn)
      heart_beat_cnt_hbus_clk <= 26'h0; //0x3FFFFFF
  else
      heart_beat_cnt_hbus_clk <= heart_beat_cnt_hbus_clk + 1'b1;

//Heart beat by 50MHz clock
always @(posedge c10_clk50m or negedge c10_resetn)
  if (!c10_resetn)
      heart_beat_cnt <= 26'h0; //0x3FFFFFF
  else
      heart_beat_cnt <= heart_beat_cnt + 1'b1;
      
assign user_led[0] = heart_beat_cnt_clk_125m[25];
assign user_led[1] = heart_beat_cnt_clk_adj[25];
assign user_led[2] = heart_beat_cnt_hbus_clk[25];
assign user_led[3] = heart_beat_cnt[25];

endmodule
